@@ -38,8 +38,6 @@
 #include <jack/jack.h>
 #include <jack/midiport.h>
 
-#include "fluid_lash.h"
-
 
 typedef struct _fluid_jack_audio_driver_t fluid_jack_audio_driver_t;
 typedef struct _fluid_jack_midi_driver_t fluid_jack_midi_driver_t;
@@ -162,7 +160,7 @@ new_fluid_jack_client(fluid_settings_t *settings, int isaudio, void *driver)
     fluid_mutex_lock(last_client_mutex);      /* ++ lock last_client */
 
     /* If the last client uses the same server and is not the same type (audio or MIDI),
-     * then re-use the client. */
+     * then reuse the client. */
     if(last_client &&
             (last_client->server != NULL && server != NULL && FLUID_STRCMP(last_client->server, server) == 0) &&
             ((!isaudio && last_client->midi_driver == NULL) || (isaudio && last_client->audio_driver == NULL)))
@@ -265,19 +263,6 @@ new_fluid_jack_client(fluid_settings_t *settings, int isaudio, void *driver)
         goto error_recovery;
     }
 
-    /* tell the lash server our client name */
-#ifdef HAVE_LASH
-    {
-        int enable_lash = 0;
-        fluid_settings_getint(settings, "lash.enable", &enable_lash);
-
-        if(enable_lash)
-        {
-            fluid_lash_jack_client_name(fluid_lash_client, name);
-        }
-    }
-#endif /* HAVE_LASH */
-
     client_ref->server = server;        /* !! takes over allocation */
     server = NULL;      /* Set to NULL so it doesn't get freed below */
 
@@ -612,7 +597,7 @@ new_fluid_jack_audio_driver2(fluid_settings_t *settings, fluid_audio_func_t func
 
     if(autoconnect)
     {
-        jack_ports = jack_get_ports(client, NULL, NULL, JackPortIsInput | JackPortIsPhysical);
+        jack_ports = jack_get_ports(client, NULL, JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput | JackPortIsPhysical);
 
         if(jack_ports && jack_ports[0])
         {
