@@ -859,11 +859,6 @@ fluid_voice_update_param(fluid_voice_t *voice, int gen)
         break;
 
     case GEN_FILTERFC:
-        /* The resonance frequency is converted from absolute cents to
-         * midicents .val and .mod are both used, this permits real-time
-         * modulation.  The allowed range is tested in the 'fluid_ct2hz'
-         * function [PH,20021214]
-         */
         UPDATE_RVOICE_GENERIC_R1(fluid_iir_filter_set_fres, &voice->rvoice->resonant_filter, x);
         break;
 
@@ -1404,14 +1399,12 @@ fluid_voice_kill_excl(fluid_voice_t *voice)
     fluid_voice_gen_set(voice, GEN_EXCLUSIVECLASS, 0);
 
     /* Speed up the volume envelope */
-    /* The value was found through listening tests with hi-hat samples. */
-    fluid_voice_gen_set(voice, GEN_VOLENVRELEASE, -200);
+    /* The previously-used value of "-200" was found through listening tests
+       with hi-hat samples. This was changed to "-2000" after "-200" was shown
+       to cause too long cut times in most cases. */
+    fluid_voice_gen_set(voice, GEN_VOLENVRELEASE, -2000);
     fluid_voice_update_param(voice, GEN_VOLENVRELEASE);
 
-    /* Speed up the modulation envelope */
-    fluid_voice_gen_set(voice, GEN_MODENVRELEASE, -200);
-    fluid_voice_update_param(voice, GEN_MODENVRELEASE);
-
     at_tick = fluid_channel_get_min_note_length_ticks(voice->channel);
     UPDATE_RVOICE_I1(fluid_rvoice_noteoff, at_tick);
 
@@ -1791,7 +1784,7 @@ fluid_voice_get_lower_boundary_for_attenuation(fluid_voice_t *voice)
                3)absolute value of amount.
 
                When at least one source mapping is bipolar:
-			     min_val is -|amount| regardless the sign of amount.
+                 min_val is -|amount| regardless the sign of amount.
                When both sources mapping are unipolar:
                  min_val is -|amount|, if amount is negative.
                  min_val is 0, if amount is positive
@@ -1834,9 +1827,6 @@ fluid_voice_get_lower_boundary_for_attenuation(fluid_voice_t *voice)
     return lower_bound;
 }
 
-
-
-
 int fluid_voice_set_param(fluid_voice_t *voice, int gen, fluid_real_t nrpn_value)
 {
     voice->gen[gen].nrpn = nrpn_value;
